package vip.xiaonuo.production.service.impl;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import vip.xiaonuo.production.entity.ProductionWritePlan;
import vip.xiaonuo.production.entity.ProductionYield;
import vip.xiaonuo.production.mapper.ProductionWritePlanMapper;
import vip.xiaonuo.production.mapper.ProductionYieldMapper;
import vip.xiaonuo.production.param.ProductionYieldParam;
import vip.xiaonuo.production.service.IProductionYieldService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.lang.reflect.WildcardType;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 生成管控产量情况 服务实现类
 * </p>
 *
 * @author author
 * @since 2024-12-12
 */
@Service
public class ProductionYieldServiceImpl extends ServiceImpl<ProductionYieldMapper, ProductionYield> implements IProductionYieldService {

    @Autowired
    private ProductionYieldMapper yieldMapper;
    @Autowired
    private ProductionWritePlanMapper writePlanMapper;

    @Override
    public List<ProductionYield> getList(ProductionYieldParam yieldParam) {
        String orgId = yieldParam.getOrgId();
        Integer timeType = yieldParam.getTimeType();
        String locationName = yieldParam.getLocationName();
        String produceName = yieldParam.getProduceName();
        QueryWrapper<ProductionYield> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(StringUtils.isNotBlank(orgId), "org_id", orgId)
                .eq(StringUtils.isNotBlank(locationName),"location_name",locationName);
        if (StringUtils.isNotBlank(locationName)) {
            queryWrapper.like(StringUtils.isNotBlank(produceName), "produce_name", produceName);
        }

        queryWrapper.select(" convert(IFNULL(sum(actual_production),'0'),decimal(10,2)) actualProduction,create_time createTime");
        if (0 == timeType) {
            queryWrapper.groupBy("DATE_FORMAT(create_time,'%Y')");
        } else {
            queryWrapper.groupBy("DATE_FORMAT(create_time,'%Y-%m')");
        }
        queryWrapper.orderByAsc("create_time");
//        List<ProductionWritePlan> writePlans = writePlanMapper.selectList(queryWrapper);
        List<ProductionYield> productionYields = yieldMapper.selectList(queryWrapper);
        BigDecimal math = new BigDecimal("10000");

        for (ProductionYield productionYield : productionYields) {
            BigDecimal bg = new BigDecimal(productionYield.getActualProduction());
            productionYield.setActualProduction(bg.divide(math, 2, RoundingMode.HALF_UP).toString());

            QueryWrapper<ProductionWritePlan> queryWrapper1 = new QueryWrapper<>();
            if (0 == timeType) {
                SimpleDateFormat sdf = new SimpleDateFormat("yyyy");
                String format = sdf.format(productionYield.getCreateTime());
                queryWrapper1.between("create_time", format + "-01-01 00:00:00", format + "-12-31 23:59:59");
            } else {
                SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM");
                String format = sdf.format(productionYield.getCreateTime());
                queryWrapper1.between("create_time", format + "-01 00:00:00", format + "-31 23:59:59");
            }
            queryWrapper1.select("convert(IFNULL(sum(production_plan),'0'),decimal(10,2)) productionPlan");
            ProductionWritePlan writePlan = writePlanMapper.selectOne(queryWrapper1);
            if (ObjectUtil.isEmpty(writePlan) || "0".equals(writePlan.getProductionPlan())) {
                productionYield.setCompleteRate("0");
                productionYield.setPlanProduction("0");
            } else {
                double v = Double.valueOf(productionYield.getActualProduction()) / Double.valueOf(writePlan.getProductionPlan());
                DecimalFormat def = new DecimalFormat("0.00");
                productionYield.setPlanProduction(writePlan.getProductionPlan());
                if (v > 1.0) {
                    productionYield.setCompleteRate("100");
                } else {
                    productionYield.setCompleteRate(def.format(v * 100));
                }
            }
        }
        return productionYields;
    }

}
